"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.filterFn$ = exports.selectedLanguages$ = exports.setLangs = void 0;

var _rxjs = require("rxjs");

var _operators = require("rxjs/operators");

var _config = _interopRequireDefault(require("part:language-switcher/config"));

var _lodash = require("lodash");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var onSelect$ = new _rxjs.Subject();

var setLangs = function setLangs(langs) {
  return onSelect$.next(langs);
};

exports.setLangs = setLangs;

var persistOn = function persistOn(key, defaultValue) {
  return function (input$) {
    var persisted;

    try {
      persisted = JSON.parse(window.localStorage.getItem(key));
    } catch (err) {} // eslint-disable-line no-empty


    return input$.pipe((0, _operators.startWith)(persisted || defaultValue), (0, _operators.tap)(function (value) {
      window.localStorage.setItem(key, JSON.stringify(value));
    }));
  };
};

var SUPPORTED_LANG_IDS = _config["default"].supportedLanguages.map(function (lang) {
  return lang.id;
});

var selectedLanguages$ = onSelect$.pipe((0, _operators.map)(function (selectedLangs) {
  return [(0, _lodash.intersection)(selectedLangs, SUPPORTED_LANG_IDS)[0]];
}), (0, _operators.publishReplay)(1), (0, _operators.refCount)(), persistOn("@sanity/plugin/language-switcher/selected-languages", SUPPORTED_LANG_IDS));
exports.selectedLanguages$ = selectedLanguages$;

var defaultFilterField = function defaultFilterField(enclosingType, field, selectedLanguages) {
  return !enclosingType.name.startsWith("locale") || selectedLanguages.includes(field.name);
};

var filterField = _config["default"].filterField || defaultFilterField;
var filterFn$ = selectedLanguages$.pipe((0, _operators.map)(function (langs) {
  return function (enclosingType, field) {
    return filterField(enclosingType, field, [langs[0]]);
  };
}));
exports.filterFn$ = filterFn$;